---
annotations_creators:
- found
language_creators:
- found
languages:
  XNLI:
  - ar
  - bg
  - de
  - el
  - en
  - es
  - fr
  - hi
  - ru
  - sw
  - th
  - tr
  - ur
  - vi
  - zh
  PAWS-X.en:
  - en
  PAWS-X.de:
  - de
  PAWS-X.es:
  - es
  PAWS-X.fr:
  - fr
  PAWS-X.ja:
  - ja
  PAWS-X.ko:
  - ko
  PAWS-X.zh:
  - zh
  udpos.Afrikans:
  - af
  udpos.Arabic:
  - ar
  udpos.Basque:
  - eu
  udpos.Bulgarian:
  - bg
  udpos.Dutch:
  - nl
  udpos.English:
  - en
  udpos.Estonian:
  - et
  udpos.Finnish:
  - fi
  udpos.French:
  - fr
  udpos.German:
  - de
  udpos.Greek:
  - el
  udpos.Hebrew:
  - he
  udpos.Hindi:
  - hi
  udpos.Hungarian:
  - hu
  udpos.Indonesian:
  - id
  udpos.Italian:
  - it
  udpos.Japanese:
  - ja
  udpos.Kazakh:
  - kk
  udpos.Korean:
  - ko
  udpos.Chinese:
  - zh
  udpos.Marathi:
  - mr
  udpos.Persian:
  - fa
  udpos.Portuguese:
  - pt
  udpos.Russian:
  - ru
  udpos.Spanish:
  - es
  udpos.Tagalog:
  - tl
  udpos.Tamil:
  - ta
  udpos.Telugu:
  - te
  udpos.Thai:
  - th
  udpos.Turkish:
  - tr
  udpos.Urdu:
  - ur
  udpos.Vietnamese:
  - vi
  udpos.Yoruba:
  - yo
  PAN-X.af:
  - af
  PAN-X.ar:
  - ar
  PAN-X.bg:
  - bg
  PAN-X.bn:
  - bn
  PAN-X.de:
  - de
  PAN-X.el:
  - el
  PAN-X.en:
  - en
  PAN-X.es:
  - es
  PAN-X.et:
  - et
  PAN-X.eu:
  - eu
  PAN-X.fa:
  - fa
  PAN-X.fi:
  - fi
  PAN-X.fr:
  - fr
  PAN-X.he:
  - he
  PAN-X.hi:
  - hi
  PAN-X.hu:
  - hu
  PAN-X.id:
  - id
  PAN-X.it:
  - it
  PAN-X.ja:
  - ja
  PAN-X.jv:
  - jv
  PAN-X.ka:
  - ka
  PAN-X.kk:
  - kk
  PAN-X.ko:
  - ko
  PAN-X.ml:
  - ml
  PAN-X.mr:
  - mr
  PAN-X.ms:
  - ms
  PAN-X.my:
  - my
  PAN-X.nl:
  - nl
  PAN-X.pt:
  - pt
  PAN-X.ru:
  - ru
  PAN-X.sw:
  - sw
  PAN-X.ta:
  - ta
  PAN-X.te:
  - te
  PAN-X.th:
  - th
  PAN-X.tl:
  - tl
  PAN-X.tr:
  - tr
  PAN-X.ur:
  - ur
  PAN-X.vi:
  - vi
  PAN-X.yo:
  - yo
  PAN-X.zh:
  - zh
  XQuAD:
  - ar
  - de
  - vi
  - zh
  - en
  - es
  - hi
  - el
  - ru
  - th
  - tr
  MLQA.ar.ar:
  - ar
  MLQA.ar.de:
  - ar
  - de
  MLQA.ar.vi:
  - ar
  - vi
  MLQA.ar.zh:
  - ar
  - zh
  MLQA.ar.en:
  - ar
  - en
  MLQA.ar.es:
  - ar
  - es
  MLQA.ar.hi:
  - ar
  - hi
  MLQA.de.ar:
  - de
  - ar
  MLQA.de.de:
  - de
  MLQA.de.vi:
  - de
  - vi
  MLQA.de.zh:
  - de
  - zh
  MLQA.de.en:
  - de
  - en
  MLQA.de.es:
  - de
  - es
  MLQA.de.hi:
  - de
  - hi
  MLQA.vi.ar:
  - vi
  - ar
  MLQA.vi.de:
  - vi
  - de
  MLQA.vi.vi:
  - vi
  MLQA.vi.zh:
  - vi
  - zh
  MLQA.vi.en:
  - vi
  - en
  MLQA.vi.es:
  - vi
  - es
  MLQA.vi.hi:
  - vi
  - hi
  MLQA.zh.ar:
  - zh
  - ar
  MLQA.zh.de:
  - zh
  - de
  MLQA.zh.vi:
  - zh
  - vi
  MLQA.zh.zh:
  - zh
  MLQA.zh.en:
  - zh
  - en
  MLQA.zh.es:
  - zh
  - es
  MLQA.zh.hi:
  - zh
  - hi
  MLQA.en.ar:
  - en
  - ar
  MLQA.en.de:
  - en
  - de
  MLQA.en.vi:
  - en
  - vi
  MLQA.en.zh:
  - en
  - zh
  MLQA.en.en:
  - en
  MLQA.en.es:
  - en
  - es
  MLQA.en.hi:
  - en
  - hi
  MLQA.es.ar:
  - es
  - ar
  MLQA.es.de:
  - es
  - de
  MLQA.es.vi:
  - es
  - vi
  MLQA.es.zh:
  - es
  - zh
  MLQA.es.en:
  - es
  - en
  MLQA.es.es:
  - es
  MLQA.es.hi:
  - es
  - hi
  MLQA.hi.ar:
  - hi
  - ar
  MLQA.hi.de:
  - hi
  - de
  MLQA.hi.vi:
  - hi
  - vi
  MLQA.hi.zh:
  - hi
  - zh
  MLQA.hi.en:
  - hi
  - en
  MLQA.hi.es:
  - hi
  - es
  MLQA.hi.hi:
  - hi
  tydiqa:
  - fi
  - te
  - ru
  - ar
  - id
  - en
  - sw
  - ko
  - bn
  bucc18.de:
  - de
  bucc18.fr:
  - fr
  bucc18.zh:
  - zh
  bucc18.ru:
  - ru
  tatoeba.afr:
  - af
  tatoeba.ara:
  - ar
  tatoeba.ben:
  - bn
  tatoeba.bul:
  - bg
  tatoeba.deu:
  - de
  tatoeba.cmn:
  - zh
  tatoeba.ell:
  - el
  tatoeba.est:
  - et
  tatoeba.eus:
  - eu
  tatoeba.fin:
  - fi
  tatoeba.fra:
  - fr
  tatoeba.heb:
  - he
  tatoeba.hin:
  - hi
  tatoeba.hun:
  - hu
  tatoeba.ind:
  - id
  tatoeba.ita:
  - it
  tatoeba.jav:
  - jv
  tatoeba.jpn:
  - ja
  tatoeba.kat:
  - ka
  tatoeba.kaz:
  - kk
  tatoeba.kor:
  - ko
  tatoeba.mal:
  - ml
  tatoeba.mar:
  - mr
  tatoeba.nld:
  - nl
  tatoeba.pes:
  - fa-IR
  tatoeba.por:
  - pt
  tatoeba.rus:
  - ru
  tatoeba.spa:
  - es
  tatoeba.swh:
  - sw
  tatoeba.tam:
  - ta
  tatoeba.tel:
  - te
  tatoeba.tgl:
  - tl
  tatoeba.tha:
  - th
  tatoeba.tur:
  - tr
  tatoeba.urd:
  - ur
  tatoeba.vie:
  - vi
  SQuAD:
  - en
licenses:
- apache-2.0
- cc-by-4.0
- cc-by-2.0
- cc-by-sa-4.0
- other-Licence Universal Dependencies v2.5
- cc-by-nc-4.0
multilinguality:
- multilingual
- translation
size_categories:
- n<1K
- 1K<n<10K
- 10K<n<100K
- 100K<n<1M
source_datasets:
- extended|xnli
- extended|paws-x
- extended|wikiann
- extended|xquad
- extended|mlqa
- extended|tydiqa
- extended|tatoeba
- extended|squad
task_categories:
- question-answering
- structure-prediction
- text-classification
- text-retrieval
task_ids:
- open-domain-qa
- multiple-choice-qa
- extractive-qa
- named-entity-recognition
- part-of-speech-tagging
- natural-language-inference
- text-classification-other-paraphrase-identification
- text-retrieval-other-parallel-sentence-retrieval
paperswithcode_id: xtreme
pretty_name: XTREME
---

# Dataset Card for "xtreme"

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** [https://github.com/google-research/xtreme](https://github.com/google-research/xtreme)
- **Repository:** [More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)
- **Paper:** [More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)
- **Point of Contact:** [More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)
- **Size of downloaded dataset files:** 15143.21 MB
- **Size of the generated dataset:** 1027.42 MB
- **Total amount of disk used:** 16170.64 MB

### Dataset Summary

The Cross-lingual Natural Language Inference (XNLI) corpus is a crowd-sourced collection of 5,000 test and
2,500 dev pairs for the MultiNLI corpus. The pairs are annotated with textual entailment and translated into
14 languages: French, Spanish, German, Greek, Bulgarian, Russian, Turkish, Arabic, Vietnamese, Thai, Chinese,
Hindi, Swahili and Urdu. This results in 112.5k annotated pairs. Each premise can be associated with the
corresponding hypothesis in the 15 languages, summing up to more than 1.5M combinations. The corpus is made to
evaluate how to perform inference in any language (including low-resources ones like Swahili or Urdu) when only
English NLI data is available at training time. One solution is cross-lingual sentence encoding, for which XNLI
is an evaluation benchmark.
The Cross-lingual TRansfer Evaluation of Multilingual Encoders (XTREME) benchmark is a benchmark for the evaluation of
the cross-lingual generalization ability of pre-trained multilingual models. It covers 40 typologically diverse languages
(spanning 12 language families) and includes nine tasks that collectively require reasoning about different levels of
syntax and semantics. The languages in XTREME are selected to maximize language diversity, coverage in existing tasks,
and availability of training data. Among these are many under-studied languages, such as the Dravidian languages Tamil
(spoken in southern India, Sri Lanka, and Singapore), Telugu and Malayalam (spoken mainly in southern India), and the
Niger-Congo languages Swahili and Yoruba, spoken in Africa.

### Supported Tasks and Leaderboards

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Languages

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

## Dataset Structure

We show detailed information for up to 5 configurations of the dataset.

### Data Instances

#### MLQA.ar.ar

- **Size of downloaded dataset files:** 72.21 MB
- **Size of the generated dataset:** 8.77 MB
- **Total amount of disk used:** 80.98 MB

An example of 'validation' looks as follows.
```

```

#### MLQA.ar.de

- **Size of downloaded dataset files:** 72.21 MB
- **Size of the generated dataset:** 2.43 MB
- **Total amount of disk used:** 74.64 MB

An example of 'validation' looks as follows.
```

```

#### MLQA.ar.en

- **Size of downloaded dataset files:** 72.21 MB
- **Size of the generated dataset:** 8.62 MB
- **Total amount of disk used:** 80.83 MB

An example of 'validation' looks as follows.
```

```

#### MLQA.ar.es

- **Size of downloaded dataset files:** 72.21 MB
- **Size of the generated dataset:** 3.12 MB
- **Total amount of disk used:** 75.33 MB

An example of 'validation' looks as follows.
```

```

#### MLQA.ar.hi

- **Size of downloaded dataset files:** 72.21 MB
- **Size of the generated dataset:** 3.17 MB
- **Total amount of disk used:** 75.38 MB

An example of 'validation' looks as follows.
```

```

### Data Fields

The data fields are the same among all splits.

#### MLQA.ar.ar
- `id`: a `string` feature.
- `title`: a `string` feature.
- `context`: a `string` feature.
- `question`: a `string` feature.
- `answers`: a dictionary feature containing:
  - `answer_start`: a `int32` feature.
  - `text`: a `string` feature.

#### MLQA.ar.de
- `id`: a `string` feature.
- `title`: a `string` feature.
- `context`: a `string` feature.
- `question`: a `string` feature.
- `answers`: a dictionary feature containing:
  - `answer_start`: a `int32` feature.
  - `text`: a `string` feature.

#### MLQA.ar.en
- `id`: a `string` feature.
- `title`: a `string` feature.
- `context`: a `string` feature.
- `question`: a `string` feature.
- `answers`: a dictionary feature containing:
  - `answer_start`: a `int32` feature.
  - `text`: a `string` feature.

#### MLQA.ar.es
- `id`: a `string` feature.
- `title`: a `string` feature.
- `context`: a `string` feature.
- `question`: a `string` feature.
- `answers`: a dictionary feature containing:
  - `answer_start`: a `int32` feature.
  - `text`: a `string` feature.

#### MLQA.ar.hi
- `id`: a `string` feature.
- `title`: a `string` feature.
- `context`: a `string` feature.
- `question`: a `string` feature.
- `answers`: a dictionary feature containing:
  - `answer_start`: a `int32` feature.
  - `text`: a `string` feature.

### Data Splits

|   name   |validation|test|
|----------|---------:|---:|
|MLQA.ar.ar|       517|5335|
|MLQA.ar.de|       207|1649|
|MLQA.ar.en|       517|5335|
|MLQA.ar.es|       161|1978|
|MLQA.ar.hi|       186|1831|

## Dataset Creation

### Curation Rationale

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

#### Who are the source language producers?

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Annotations

#### Annotation process

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

#### Who are the annotators?

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Personal and Sensitive Information

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Discussion of Biases

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Other Known Limitations

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

## Additional Information

### Dataset Curators

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Licensing Information

[More Information Needed](https://github.com/huggingface/datasets/blob/master/CONTRIBUTING.md#how-to-contribute-to-the-dataset-cards)

### Citation Information

```
  @InProceedings{conneau2018xnli,
  author = {Conneau, Alexis
                 and Rinott, Ruty
                 and Lample, Guillaume
                 and Williams, Adina
                 and Bowman, Samuel R.
                 and Schwenk, Holger
                 and Stoyanov, Veselin},
  title = {XNLI: Evaluating Cross-lingual Sentence Representations},
  booktitle = {Proceedings of the 2018 Conference on Empirical Methods
               in Natural Language Processing},
  year = {2018},
  publisher = {Association for Computational Linguistics},
  location = {Brussels, Belgium},
}
@article{hu2020xtreme,
      author    = {Junjie Hu and Sebastian Ruder and Aditya Siddhant and Graham Neubig and Orhan Firat and Melvin Johnson},
      title     = {XTREME: A Massively Multilingual Multi-task Benchmark for Evaluating Cross-lingual Generalization},
      journal   = {CoRR},
      volume    = {abs/2003.11080},
      year      = {2020},
      archivePrefix = {arXiv},
      eprint    = {2003.11080}
}

```


### Contributions

Thanks to [@thomwolf](https://github.com/thomwolf), [@jplu](https://github.com/jplu), [@lewtun](https://github.com/lewtun), [@lvwerra](https://github.com/lvwerra), [@lhoestq](https://github.com/lhoestq), [@patrickvonplaten](https://github.com/patrickvonplaten), [@mariamabarham](https://github.com/mariamabarham) for adding this dataset.